library iws_device_info;

import 'package:iws_device_info/src/device_service.dart';

import 'src/device_model.dart';

export 'src/device_model.dart';

class IwsDeviceInfo {
  /// Retrieves the platform name of the device.
  ///
  /// Returns:
  ///   - `PlatformName?`: The platform name of the device, or `null` if the platform name
  ///     cannot be determined.
  static PlatformName? getDevicePlatformName() =>
      DeviceService.getDevicePlatformName();

  /// Retrieves the device information for a given device ID and user identifier.
  ///
  /// Parameters:
  ///   - deviceId: (optional) The ID of the device.
  ///   - userIdentifier: (optional) The user identifier associated with the device.
  ///
  /// Returns:
  ///   - A `Future` that resolves to an `AppDevice` object containing the device information.
  static Future<AppDevice> getDeviceInfo(
          {String? deviceId, String? userIdentifier}) =>
      DeviceService.getDeviceInfo(
          deviceId: deviceId, userIdentifier: userIdentifier);

  /// Checks if the current platform is web or desktop.
  static bool isWebOrDesktop() => DeviceService.isWebOrDesktop();

  /// Checks if the current platform is mobile.
  static bool isMobile() => DeviceService.isMobile();

  /// Retrieves the platform from the given name.
  static PlatformName? getPlatformByName(String name) =>
      DeviceService.getPlatformByName(name);

  /// Checks if the current platform is web.
  static bool isWeb() => DeviceService.isWeb();

  /// Checks if the current platform is Windows.
  static bool isWindows() => DeviceService.isWindows();

  /// Checks if the current platform is macOS.
  static bool isMacOS() => DeviceService.isMacOS();

  /// Checks if the current platform is Linux.
  static bool isLinux() => DeviceService.isLinux();

  /// Checks if the current platform is Android.
  static bool isAndroid() => DeviceService.isAndroid();

  /// Checks if the current platform is iOS.
  static bool isIOS() => DeviceService.isIOS();

  /// Checks if the current platform is an Apple device.
  static bool isAppleDevice() => DeviceService.isAppleDevice();
}
